package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.RecordOutStoreMapper;
import com.aucma.base.domain.RecordOutStore;
import com.aucma.base.service.IRecordOutStoreService;

/**
 * 出库记录Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-21
 */
@Service
public class RecordOutStoreServiceImpl implements IRecordOutStoreService 
{
    @Autowired
    private RecordOutStoreMapper recordOutStoreMapper;

    /**
     * 查询出库记录
     * 
     * @param objId 出库记录主键
     * @return 出库记录
     */
    @Override
    public RecordOutStore selectRecordOutStoreByObjId(Long objId)
    {
        return recordOutStoreMapper.selectRecordOutStoreByObjId(objId);
    }

    /**
     * 查询出库记录列表
     * 
     * @param recordOutStore 出库记录
     * @return 出库记录
     */
    @Override
    public List<RecordOutStore> selectRecordOutStoreList(RecordOutStore recordOutStore)
    {
        return recordOutStoreMapper.selectRecordOutStoreList(recordOutStore);
    }

    /**
     * 新增出库记录
     * 
     * @param recordOutStore 出库记录
     * @return 结果
     */
    @Override
    public int insertRecordOutStore(RecordOutStore recordOutStore)
    {
        return recordOutStoreMapper.insertRecordOutStore(recordOutStore);
    }

    /**
     * 修改出库记录
     * 
     * @param recordOutStore 出库记录
     * @return 结果
     */
    @Override
    public int updateRecordOutStore(RecordOutStore recordOutStore)
    {
        return recordOutStoreMapper.updateRecordOutStore(recordOutStore);
    }

    /**
     * 批量删除出库记录
     * 
     * @param objIds 需要删除的出库记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordOutStoreByObjIds(Long[] objIds)
    {
        return recordOutStoreMapper.deleteRecordOutStoreByObjIds(objIds);
    }

    /**
     * 删除出库记录信息
     * 
     * @param objId 出库记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordOutStoreByObjId(Long objId)
    {
        return recordOutStoreMapper.deleteRecordOutStoreByObjId(objId);
    }
}
