package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.RecordOutStore;
import com.aucma.base.service.IRecordOutStoreService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 出库记录Controller
 *
 * @author Yinq
 * @date 2023-09-21
 */
@RestController
@RequestMapping("/base/outStore" )
public class RecordOutStoreController extends BaseController {
    @Autowired
    private IRecordOutStoreService recordOutStoreService;

    /**
     * 查询出库记录列表
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(RecordOutStore recordOutStore) {
        startPage();
        List<RecordOutStore> list = recordOutStoreService.selectRecordOutStoreList(recordOutStore);
        return getDataTable(list);
    }

    /**
     * 导出出库记录列表
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:export')" )
    @Log(title = "出库记录" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, RecordOutStore recordOutStore) {
        List<RecordOutStore> list = recordOutStoreService.selectRecordOutStoreList(recordOutStore);
        ExcelUtil<RecordOutStore> util = new ExcelUtil<RecordOutStore>(RecordOutStore. class);
        util.exportExcel(response, list, "出库记录数据" );
    }

    /**
     * 获取出库记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(recordOutStoreService.selectRecordOutStoreByObjId(objId));
    }

    /**
     * 新增出库记录
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:add')" )
    @Log(title = "出库记录" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordOutStore recordOutStore) {
        recordOutStore.setCreatedBy(getUsername());
        recordOutStore.setCreatedTime(DateUtils.getNowDate());
        return toAjax(recordOutStoreService.insertRecordOutStore(recordOutStore));
    }

    /**
     * 修改出库记录
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:edit')" )
    @Log(title = "出库记录" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordOutStore recordOutStore) {
        recordOutStore.setUpdatedBy(getUsername());
        recordOutStore.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(recordOutStoreService.updateRecordOutStore(recordOutStore));
    }

    /**
     * 删除出库记录
     */
    @PreAuthorize("@ss.hasPermi('base:outStore:remove')" )
    @Log(title = "出库记录" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordOutStoreService.deleteRecordOutStoreByObjIds(objIds));
    }
}
